==> liquidwar6-0.0.1beta.tar.gz: liquidwar6-0.0.1beta/src/lib/map/map-param.c <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#include <stdlib.h>
#include <string.h>

#include "config.h"
#include "map.h"
#include "map-internal.h"

void
lw6map_param_defaults (LW6MAP_PARAM * param)
{
  lw6opt_static_defaults (&(param->options));
  lw6map_style_defaults (&(param->style));
}

/*
 * Read the param associated to a map. Pointer to param must be valid,
 * it's modified in-place.
 */
int
lw6map_param_read (LW6MAP_PARAM * param, char *dirname)
{
  int ret = 0;

  ret = lw6map_options_read (&(param->options), dirname) &&
    lw6map_style_read (&(param->style), dirname);

  return ret;
}

/*
 * Clears a param.
 */
void
lw6map_param_clear (LW6MAP_PARAM * param)
{
  if (param)
    {
      lw6map_options_clear (&(param->options));
      lw6map_style_clear (&(param->style));

      /*
       * We don't free the param pointer itself, this
       * is a "clear" function, not a "free".
       */
    }
}

/*
 * Like with clear, *dst must be either initialized or
 * totally zeroed, else function will fail (core dump)
 */
void
lw6map_param_copy (LW6MAP_PARAM * dst, LW6MAP_PARAM * src)
{
  lw6opt_static_copy (&(dst->options), &(src->options));
  lw6map_style_copy (&(dst->style), &(src->style));
}

void
lw6map_param_set_int (LW6MAP_PARAM * param, char *key, int value)
{
}

void
lw6map_param_set_bool (LW6MAP_PARAM * param, char *key, int value)
{
}

void
lw6map_param_set_float (LW6MAP_PARAM * param, char *key, float value)
{
}

void
lw6map_param_set_string (LW6MAP_PARAM * param, char *key, char *value)
{
}

/*
 * For colors, we should probably read them as strings, or have
 * the right type in Guile.
 */

==> liquidwar6-0.0.2beta.tar.gz: liquidwar6-0.0.2beta/src/lib/map/map-param.c <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#include <stdlib.h>
#include <string.h>

#include "config.h"
#include "map.h"
#include "map-internal.h"

void
lw6map_param_defaults (LW6MAP_PARAM * param)
{
  lw6opt_static_defaults (&(param->options));
  lw6map_style_defaults (&(param->style));
}

/*
 * Read the param associated to a map. Pointer to param must be valid,
 * it's modified in-place.
 */
int
lw6map_param_read (LW6MAP_PARAM * param, char *dirname)
{
  int ret = 0;

  ret = lw6map_options_read (&(param->options), dirname) &&
    lw6map_style_read (&(param->style), dirname);

  return ret;
}

/*
 * Clears a param.
 */
void
lw6map_param_clear (LW6MAP_PARAM * param)
{
  if (param)
    {
      lw6map_options_clear (&(param->options));
      lw6map_style_clear (&(param->style));

      /*
       * We don't free the param pointer itself, this
       * is a "clear" function, not a "free".
       */
    }
}

/*
 * Like with clear, *dst must be either initialized or
 * totally zeroed, else function will fail (core dump)
 */
void
lw6map_param_copy (LW6MAP_PARAM * dst, LW6MAP_PARAM * src)
{
  lw6opt_static_copy (&(dst->options), &(src->options));
  lw6map_style_copy (&(dst->style), &(src->style));
}

void
lw6map_param_set_int (LW6MAP_PARAM * param, char *key, int value)
{
}

void
lw6map_param_set_bool (LW6MAP_PARAM * param, char *key, int value)
{
}

void
lw6map_param_set_float (LW6MAP_PARAM * param, char *key, float value)
{
}

void
lw6map_param_set_string (LW6MAP_PARAM * param, char *key, char *value)
{
}

/*
 * For colors, we should probably read them as strings, or have
 * the right type in Guile.
 */
